PyLogGrid is a Python-based framework for running and analyzing numerical simulations on [log-lattices [1]](https://www.doi.org/10.1088/1361-6544/abef73). The log-lattice structure is particularly useful for modeling phenomena that exhibit multi-scale behavior, such as turbulence. PyLogGrid is designed to be flexible, customizable, and easy to use.

This framework has been used in several scientific papers such as [[2]](https://www.doi.org/10.1017/jfm.2023.204), [[3]](https://www.doi.org/10.1103/PhysRevE.107.065106).

The framework includes a variety of built-in tools for analyzing simulation results, including visualization tools and post-processing scripts.

### References:

**[1]** Campolina, C. S., & Mailybaev, A. A. (2021). Fluid dynamics on logarithmic lattices. Nonlinearity, 34(7), 4684. doi:10.1088/1361-6544/abef73

**[2]** Barral, A., & Dubrulle, B. (2023). Asymptotic ultimate regime of homogeneous Rayleigh–Bénard convection on logarithmic lattices. Journal of Fluid Mechanics, 962, A2. doi:10.1017/jfm.2023.204

**[3]** Costa, G., Barral, A., & Dubrulle, B. (2023). Reversible Navier-Stokes equation on logarithmic lattices. Physical Review E, 107(6), 065106. doi:10.1103/PhysRevE.107.065106
